@@ -90,6 +90,8 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf 9.png )
@@ -120,6 +122,8 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doctop1.png )
@@ -132,8 +136,12 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf 10.png )
@@ -150,6 +158,10 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-localised.css.template )
@@ -196,8 +208,34 @@
 ( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/kuick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/webarchiver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/domtreeviewer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/smbmounter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/imgallery ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/khtmlsettings ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/validators ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/uachanger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/mediaplayer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/dirfilter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kamera ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/keduca ; rm -rf common )
